
from OFS.Folder import Folder
from Globals import DTMLFile
from DateTime import DateTime
from xmlrpclib import Server

# To make the StarRaveClient a good zope3 traveler

try:
    from StarRaveClientInterfaces import StarRaveClientManager
except:
    class StarRaveClientManager:
        pass

class StarRaveClient(Folder):

    """
    The StarRave client python tools
    """

    meta_type = 'StarRaveClient'
    version = '0-0-1'
    manage_options = (
        {'label':'Contents', 'action':'manage_main', 'target':'manage_main'},                         
        {'label': 'Properties', 'action': 'manage_editForm',},
        {'label': 'View', 'action': 'index_html',},
    )

    def __init__(self, id, title, content):
        "Inits the product with default values"
        self.id = id
        self.title = title
        self.content = content
        self.SiteUrl = 'http://www.yourhost.com/StarRaveFolder/'
        self.SiteName = 'StarRaveClient'
        self.Master = 'http://66.127.51.101:8080/StarRaveMaster/'
        self.skins_loaded = ['default', 'minimal']
        self.styles = ['ambient', 'hardcore', 'house', 'jungle', 'trance']
        self.mod_people = 0
        self.mod_groups = 0
        self.mod_events = 0
        self.mod_event_photo = 0
        self.mod_event_wrap = 0
        self.mod_event_review = 0
        self.mod_event_attendees = 0
        self.only_groups_can_add_events = 0
        self.only_groups_can_edit_events = 0
        self.site_location = 'base'


    def encryptPassword(self, clear_password):
        """encrypt a password for SQL"""
        import crypt, random
        encryptedpass = str(crypt.crypt(clear_password,'ab'))
        return encryptedpass

    def comparePassword(self, clear_password, crypt_password):
        """ Validate an encrypted password """
        import crypt, random
        if crypt.crypt(clear_password,'ab')==crypt_password:
            return 1
        else:
            return 0

    def manage_editAction(self, title, content, SiteUrl, SiteName, Master, skins_loaded, styles, mod_people=0, mod_groups=0, mod_events=0, mod_event_photo=0, mod_event_wrap=0, mod_event_review=0, mod_event_attendees=0, only_groups_can_add_events=0, only_groups_can_edit_events=0, RESPONSE=None):
        "Changes the product values"
        self.title = title
        self.content = content
        self.SiteUrl = SiteUrl
        self.SiteName = SiteName
        self.Master = Master
        self.skins_loaded = skins_loaded
        self.styles = styles
        self.mod_people = mod_people
        self.mod_groups = mod_groups
        self.mod_events = mod_events
        self.mod_event_photo = mod_event_photo
        self.mod_event_wrap = mod_event_wrap
        self.mod_event_review = mod_event_review
        self.mod_event_attendees = mod_event_attendees
        self.only_groups_can_add_events = only_groups_can_add_events
        self.only_groups_can_edit_events = only_groups_can_edit_events
        self._p_changed = 1
        RESPONSE.redirect('manage_editForm')

    def version(self):
	""" Return the version of this Master """
	return version

    def site_url(self):
	""" url of the Master main page """ 
	return self.absolute_url()

    def get_all_performers(self):
	""" get performers stored in this database"""
        ## This is used by the SR Master hsot when updating the master list ##
        result = self.SQL_get_all_performers()
        performerlist = []
        for performer in result:
            thisperformer= {}
            if performer['linktype'] == 'person':
                url = self.site_url() + "/people/view?identifier=" + str(performer['linkid'])
                identifier = performer['linkid']
                persondata = self.SQL_get_person_by_id(identifier=identifier)
                thisperson = persondata[0]
                city = thisperson['city']
                state = thisperson['state']
                country = thisperson['country']
            elif performer['linktype'] == 'group':
                identifier = performer['linkid']
                groupdata = self.SQL_get_group_by_id(identifier=identifier)
                thisgroup = groupdata[0]
                city = thisgroup['city']
                state = thisgroup['state']
                country = thisgroup['country']
                url = self.site_url() + "/groups/view?identifier=" + str(performer['linkid'])
            thisperformer['url'] = url
            thisperformer['performertitle'] = str(performer['performertitle'])
            thisperformer['description'] = performer['description']
            thisperformer['city'] = city
            thisperformer['state'] = state
            thisperformer['country'] = country
            performerlist.append(thisperformer)
	return performerlist

    def update_performer_list(self, server):
        """ get all performers from the server """
        print "[connecting to]"
        print server
        addcount = 0
        updatecount = 0
        starRaveMasterServer = Server(server)
        try:
            serverPerformers = starRaveMasterServer.get_all_performers()
        except:
            print "could not connect"
#        print serverPerformers
        self.SQL_remove_current_flags()
        if len(serverPerformers) > 0:
            for performer in serverPerformers:
#                print performer
                country = performer['country']
                state = performer['state']
                city = performer['city']
                performertitle = performer['performertitle']
                description = performer['description']
                performerurl = performer['performerurl']
                exists = self.SQL_get_serverperformer_count(performerurl=performerurl) 
                if exists[0]['count'] == 0:
                    addcount = addcount + 1
#                    print "[New, Adding]"
                    self.SQL_add_serverperformer(performerurl=performerurl, performertitle=performertitle, city=city, state=state, country=country, description=description)
                else:
#                    print "[Exists, Updating]"
                    updatecount = updatecount + 1
                    self.SQL_update_serverperformer(performerurl=performerurl, performertitle=performertitle, city=city, state=state, country=country, description=description)
        self.SQL_delete_noncurrent_records()
        return addcount + updatecount

    manage_editForm = DTMLFile('www/manage_editForm',
                                globals()) # Edit the content of the object
    # constructor pages. Only used when the product is added to a folder.

    def person_is_group_admin(self, personid, groupid):
        """ Is the person an admin for the group? """
        list = []
        dict = {}
        adminornot = 0
        result = self.SQL_person_in_group(personid=personid, groupid=groupid)
        list = result.dictionaries()
        if len(list) > 0:
            dict = list[0]
            if dict['approved'] == 1:
                if dict['membertype'] == 'owner':
                    adminornot = 1
                elif dict['membertype'] == 'admin':
                    adminornot = 1
        return adminornot

    def person_is_event_admin(self, eventid, personid):
        """ Is the person able to edit the event """
        list = []
        dict = {}
        adminornot = 0
        grouplist = self.SQL_get_eventmembership_by_eventid(eventid=eventid)
        groups = grouplist.dictionaries()
        #print groups
        if len(groups) > 0:
            for group in groups:
                #print group
                groupid = group['identifier']
                if self.person_is_group_admin(personid, groupid):
                    adminornot = 1
        return adminornot


def manage_addStarRaveClientAction(self, id='StarRaveClient', title='Title here',
                            content='Content here.', REQUEST=None):
    "Add a StarRaveClient to a folder."
    self._setObject(id, StarRaveClient(id, title, content))
    if REQUEST is not None:
        return self.manage_main(self, REQUEST)

manage_addStarRaveClientForm = DTMLFile('manage_addStarRaveClientForm',
                                  globals()) # Get user id from this form
